==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE82S.sql <==
/****************************************************************************/
/* GE82 ( DB定義書管理テーブル )                                            */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE82 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , KBTBL        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  30 ﾃｰﾌﾞﾙ区分    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  40 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      varchar           (  200 )                                      /*  50 名称         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  60 表示順       */
 , CLM_NAME     varchar           (  120 )                                      /*  70 項目名(漢字) */
 , CLM          varchar           (   30 )                  NOT NULL            /*  80 項目         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  90 DBｸﾗｽ        */
 , VIEW_LENGTH  varchar           (   10 )                                      /* 100 表示桁数     */
 , USE_LENGTH   varchar           (    9 )                                      /* 110 使用桁数     */
 , UK           varchar           (    2 )                                      /* 120 ﾕﾆｰｸｷｰ       */
 , LUK          varchar           (    2 )                                      /* 130 論理ﾕﾆｰｸｷｰ   */
 , IXA          varchar           (    2 )                                      /* 140 ｲﾝﾃﾞｯｸｽA     */
 , IXB          varchar           (    2 )                                      /* 150 ｲﾝﾃﾞｯｸｽB     */
 , IXC          varchar           (    2 )                                      /* 160 ｲﾝﾃﾞｯｸｽC     */
 , IXD          varchar           (    2 )                                      /* 170 ｲﾝﾃﾞｯｸｽD     */
 , IXE          varchar           (    2 )                                      /* 180 ｲﾝﾃﾞｯｸｽE     */
 , IXF          varchar           (    2 )                                      /* 190 ｲﾝﾃﾞｯｸｽF     */
 , IXG          varchar           (    2 )                                      /* 200 ｲﾝﾃﾞｯｸｽG     */
 , IXH          varchar           (    2 )                                      /* 210 ｲﾝﾃﾞｯｸｽH     */
 , IXI          varchar           (    2 )                                      /* 220 ｲﾝﾃﾞｯｸｽI     */
 , IXJ          varchar           (    2 )                                      /* 230 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          varchar           (    2 )                                      /* 240 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     varchar           (    1 )                                      /* 250 ﾉｯﾄﾇﾙ        */
 , RENDERER     varchar           (   10 )                                      /* 260 表示種別     */
 , EDITOR       varchar           (   10 )                                      /* 270 編集種別     */
 , DBTYPE       varchar           (   10 )                                      /* 280 文字種別     */
 , DATA_DEFAULT varchar           (  200 )                                      /* 290 初期値       */
 , KBCLM        varchar           (    1 )      DEFAULT '0' NOT NULL            /* 300 ｶﾗﾑ区分      */
 , BIKO         varchar           ( 2000 )                                      /* 310 備考         */
 , CDKH         varchar           (    1 )                                      /* 320 改廃ｺｰﾄﾞ     */
 , COMMENTS     varchar           (  500 )                                      /* 330 ｺﾒﾝﾄ         */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE82S.sql <==
/****************************************************************************/
/* GE82 ( DB定義書管理テーブル )                                            */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE82 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , KBTBL        varchar           (    1 )      DEFAULT '0' NOT NULL            /*  30 ﾃｰﾌﾞﾙ区分    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  40 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      varchar           (  200 )                                      /*  50 名称         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  60 表示順       */
 , CLM_NAME     varchar           (  120 )                                      /*  70 項目名(漢字) */
 , CLM          varchar           (   30 )                  NOT NULL            /*  80 項目         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  90 DBｸﾗｽ        */
 , VIEW_LENGTH  varchar           (   10 )                                      /* 100 表示桁数     */
 , USE_LENGTH   varchar           (    9 )                                      /* 110 使用桁数     */
 , UK           varchar           (    2 )                                      /* 120 ﾕﾆｰｸｷｰ       */
 , LUK          varchar           (    2 )                                      /* 130 論理ﾕﾆｰｸｷｰ   */
 , IXA          varchar           (    2 )                                      /* 140 ｲﾝﾃﾞｯｸｽA     */
 , IXB          varchar           (    2 )                                      /* 150 ｲﾝﾃﾞｯｸｽB     */
 , IXC          varchar           (    2 )                                      /* 160 ｲﾝﾃﾞｯｸｽC     */
 , IXD          varchar           (    2 )                                      /* 170 ｲﾝﾃﾞｯｸｽD     */
 , IXE          varchar           (    2 )                                      /* 180 ｲﾝﾃﾞｯｸｽE     */
 , IXF          varchar           (    2 )                                      /* 190 ｲﾝﾃﾞｯｸｽF     */
 , IXG          varchar           (    2 )                                      /* 200 ｲﾝﾃﾞｯｸｽG     */
 , IXH          varchar           (    2 )                                      /* 210 ｲﾝﾃﾞｯｸｽH     */
 , IXI          varchar           (    2 )                                      /* 220 ｲﾝﾃﾞｯｸｽI     */
 , IXJ          varchar           (    2 )                                      /* 230 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          varchar           (    2 )                                      /* 240 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     varchar           (    1 )                                      /* 250 ﾉｯﾄﾇﾙ        */
 , RENDERER     varchar           (   10 )                                      /* 260 表示種別     */
 , EDITOR       varchar           (   10 )                                      /* 270 編集種別     */
 , DBTYPE       varchar           (   10 )                                      /* 280 文字種別     */
 , DATA_DEFAULT varchar           (  200 )                                      /* 290 初期値       */
 , KBCLM        varchar           (    1 )      DEFAULT '0' NOT NULL            /* 300 ｶﾗﾑ区分      */
 , BIKO         varchar           ( 2000 )                                      /* 310 備考         */
 , CDKH         varchar           (    1 )                                      /* 320 改廃ｺｰﾄﾞ     */
 , COMMENTS     varchar           (  500 )                                      /* 330 ｺﾒﾝﾄ         */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
